| Title: | Helper for rOpenSci Package Developpers |
|---|---|
| Description: | Provides helpers for rOpenSci package developpers, mostly helping with metadata management (badges, DESCRIPTION) and GitHub infrastructure (GitHub issue and PR templates). |
| Authors: | Maëlle Salmon [aut, cre] (ORCID: <https://orcid.org/0000-0002-2815-0399>), Daniel Possenriede [ctb] (ORCID: <https://orcid.org/0000-0002-6738-9845>), rOpenSci [fnd] (https://ropensci.org/) |
| Maintainer: | Maëlle Salmon <[email protected]> |
| License: | GPL-3 |
| Version: | 0.0.1.900 |
| Built: | 2026-05-23 06:22:15 UTC |
| Source: | https://github.com/ropenscilabs/rodev |
No longer recommended!
add_ro_desc(path = usethis::proj_get())add_ro_desc(path = usethis::proj_get())
path |
path to package |
Add rOpenSci as funder to DESCRIPTION
add_ro_fnd(path = usethis::proj_get())add_ro_fnd(path = usethis::proj_get())
path |
path to package |
Browse packaging guidelines
read_pkg_guide()read_pkg_guide()
Names, Markdown code, href and src of repostatus.org badges as retrieved from https://github.com/jantman/repostatus.org/tree/master/badges/latest before this package release. See also http://www.repostatus.org/ The data is distributed with a CC-BY SA license. Refer to http://www.repostatus.org/
A data.frame with columns status (lowercase) and md_code.
Use CRAN checks badge
use_cchecks_badge()use_cchecks_badge()
It will help you add the CRAN checks badge to your README.
## Not run: use_cchecks_badge() ## End(Not run)## Not run: use_cchecks_badge() ## End(Not run)
Add rOpenSci docs URL to DESCRIPTION
use_docs_link()use_docs_link()
Use repostatus.org Badge
use_repostatus_badge(status)use_repostatus_badge(status)
status |
current status of the project, cf details. |
Possible statuses are rodev::repostatus_badges$status,
abandoned
active
concept
inactive
moved
suspended
unsupported
wip
For more details refer to https://www.repostatus.org.
It will help you add the repostatus.org badge to your README.
## Not run: use_repostatus_badge("wip") ## End(Not run)## Not run: use_repostatus_badge("wip") ## End(Not run)
Use rOpenSci review badge
use_review_badge(onboarding_issue_id)use_review_badge(onboarding_issue_id)
onboarding_issue_id |
Issue number of the onboarding thread of your package |
It will help you add the rOpenSci review badge to your README.
## Not run: use_review_badge(24) ## End(Not run)## Not run: use_review_badge(24) ## End(Not run)
Add issue, PR templates and CONTRIBUTING.md file in .github
use_ro_github( package_name = desc::desc_get_field("Package", file = usethis::proj_get()) )use_ro_github( package_name = desc::desc_get_field("Package", file = usethis::proj_get()) )
package_name |
Package name |